@@ -5,8 +5,8 @@ use strict;
 use warnings;
 
 package Net::DHCP;
-$Net::DHCP::VERSION = '0.7_008'; # TRIAL
-$Net::DHCP::VERSION = '0.7008';
+$Net::DHCP::VERSION = '0.7_009'; # TRIAL
+$Net::DHCP::VERSION = '0.7009';
 
 1;
 
@@ -22,7 +22,7 @@ Net::DHCP - Object methods to create a DHCP packet
 
 =head1 VERSION
 
-version 0.7_008
+version 0.7_009
 
 =head1 SYNOPSIS
 
@@ -45,11 +45,11 @@ L<Net::DHCP::Options>, L<Net::DHCP::Constants>.
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2022 by Dean Hamstead.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
