@@ -7,8 +7,8 @@ use warnings;
 use 5.8.0;
 
 package Net::DHCP::Constants;
-$Net::DHCP::Constants::VERSION = '0.7_008'; # TRIAL
-$Net::DHCP::Constants::VERSION = '0.7008';
+$Net::DHCP::Constants::VERSION = '0.7_009'; # TRIAL
+$Net::DHCP::Constants::VERSION = '0.7009';
 # standard module declaration
 our ( @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 use Exporter;
@@ -533,7 +533,7 @@ Net::DHCP::Constants - Constants for DHCP codes and options
 
 =head1 VERSION
 
-version 0.7_008
+version 0.7_009
 
 =head1 SYNOPSIS
 
@@ -820,11 +820,11 @@ L<Net::DHCP::Packet>, L<Net::DHCP::Options>
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2022 by Dean Hamstead.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
