@@ -8,8 +8,8 @@ use warnings;
 use 5.8.0;
 
 package Net::DHCP::Packet;
-$Net::DHCP::Packet::VERSION = '0.7_008'; # TRIAL
-$Net::DHCP::Packet::VERSION = '0.7008';
+$Net::DHCP::Packet::VERSION = '0.7_009'; # TRIAL
+$Net::DHCP::Packet::VERSION = '0.7009';
 use Carp;
 use Net::DHCP::Constants qw(:DEFAULT :dhcp_hashes :dhcp_other %DHO_FORMATS %SUBOPTION_FORMATS);
 use Net::DHCP::Packet::Attributes qw(:all);
@@ -518,6 +518,16 @@ sub serialize {
 
 }    # end sub serialize
 
+#=======================================================================
+sub min_len_handling {
+    my ( $self, $level )  = @_;
+    return $self->{min_len_handling} || 0 if @_ == 1;
+
+    croak( sprintf q(Invalid handle level '%s', use 0, 1, or 2.),
+        $level ) unless grep $_ eq $level, 0, 1, 2;
+    $self->{min_len_handling} = $level;
+}
+
 #=======================================================================
 sub marshall {
 
@@ -525,17 +535,25 @@ sub marshall {
     my ( $self, $buf ) = @_;
     my $opt_buf;
 
-    if ( length($buf) < BOOTP_ABSOLUTE_MIN_LEN() ) {
-        croak( sprintf
+    my $min_len_handling = $self->min_len_handling;
+    if ( $min_len_handling != 2
+         && length($buf) < BOOTP_ABSOLUTE_MIN_LEN()
+     ) {
+        my $message = sprintf
             'marshall: packet too small (%d), absolute minimum size is %d',
             length($buf),
-            BOOTP_ABSOLUTE_MIN_LEN() );
+            BOOTP_ABSOLUTE_MIN_LEN();
+        croak($message) unless $min_len_handling;
+        warn($message);
     }
-    if ( length($buf) < BOOTP_MIN_LEN() ) {
-        carp( sprintf
+    if ( $min_len_handling != 2
+         && length($buf) < BOOTP_MIN_LEN()
+     ) {
+        my $message = sprintf
             'marshall: packet too small (%d), minimum size is %d',
             length($buf),
-            BOOTP_MIN_LEN() );
+            BOOTP_MIN_LEN();
+        carp($message);
     }
     if ( length($buf) > DHCP_MAX_MTU() ) {
         croak( sprintf
@@ -863,7 +881,7 @@ Net::DHCP::Packet - Object methods to create a DHCP packet.
 
 =head1 VERSION
 
-version 0.7_008
+version 0.7_009
 
 =head1 SYNOPSIS
 
@@ -1335,6 +1353,20 @@ For option 43 (vendor specific), 82 (relay agent) etc.
 
 Unpacks sub-options to a list of lists
 
+=item min_len_handling ( LEVEL )
+
+By default, the level is set to 0. If the packet is shorter than the
+minimum C<BOOTP_MIN_LEN>, a warning is issued; if it is shorter than
+the absolute minimum C<BOOTP_ABSOLUTE_MIN_LEN>, an exception is
+thrown.
+
+If the level is set to 1, even the absolute minimum just warns.
+
+Setting the level to 2 means the packet length checks are skipped
+altogether.
+
+Without a parameter, the method returns the current level.
+
 =back
 
 See also L<Net::DHCP::Packet::IPv4Utils>
@@ -1430,11 +1462,11 @@ L<Net::DHCP::Attributes>, L<Net::DHCP::OrderOptions>.
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dean Hamstad.
+This software is copyright (c) 2022 by Dean Hamstead.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
